@@ -39,7 +39,7 @@ async def upsert_model(collection: Collection, select_type: TypeSelector,
     result = await collection.update_one(where,
                                          {'$set': to_mongo(insert.dict(exclude_unset=True))},
                                          upsert=True)
-    obj_id = result.upserted_id or getattr(insert, 'id')
+    obj_id = result.upserted_id or getattr(insert, 'id', None)
     if obj_id:
         doc = await collection.find_one({'_id': ObjectId(obj_id)})
     else:
